pub struct DecodeExportError(DecodeExportErrorKind);Expand description
Errors raised by decode_result_export.
Tuple Fields
0: DecodeExportErrorKindImplementations
Sourceimpl DecodeExportError
impl DecodeExportError
fn wrong_content_type(actual: String) -> Self
const fn unsupported_version(version: u32) -> Self
Sourcepub fn parcel_error(&self) -> Option<ParcelError>
pub fn parcel_error(&self) -> Option<ParcelError>
Returns the stable parcel error when envelope decoding failed.
Sourcepub fn wrong_content_type_value(&self) -> Option<&str>
pub fn wrong_content_type_value(&self) -> Option<&str>
Returns the unexpected content type when the envelope was not a result export.
Sourcepub const fn unsupported_schema_version(&self) -> Option<u32>
pub const fn unsupported_schema_version(&self) -> Option<u32>
Returns the unsupported schema version, when present.